/*
 * Copyright (c) 2002-2015 Oracle and/or its affiliates. All rights reserved.
 */

package javasoft.sqe.tests.javax.mail.Message;

import java.util.*;
import java.io.*;
import javax.mail.*;
import javax.mail.internet.*;
import com.sun.javatest.*;
import javasoft.sqe.tests.javax.mail.util.MailTest;

/**
 * This class tests the <strong>getFrom()</strong> API.
 * It does this by invoking the test api then checking
 * the type of the returned object.	<p>
 *
 *		The "From" attribute: this message to be sent. <p>
 * api2test: public Address[] getFrom()  <p>
 *
 * how2test: Call this API for given message and then check that it returned  <p>
 *	     array of addresses. Write that list out. If this operation is successfull,
 *	     then this testcase passes, otherwise it fails. <p>
 *
 *	     Returns the value of the RFC822 "From" header fields. If this <p>
 *	     header field is absent, the "Sender" header field is used. If <p>
 *	     the "Sender" is also absent, null is returned.
 */

public class getFrom_Test extends MailTest {

    public static void main( String argv[] )
    {
        getFrom_Test test = new getFrom_Test();
        Status s = test.run(argv, System.err, System.out);
	s.exit();
    }

    public Status run(String argv[], PrintWriter log, PrintWriter out)
    {
	super.run(argv, log, out);
	parseArgs(argv);	// parse command-line options

        out.println("\nTesting class Message: getFrom()\n");

        try {
          // Connect to host server
             Store store = connect2host(protocol, host, user, password);

          // Get a Folder object
	     Folder root = getRootFolder(store);
             Folder folder = root.getFolder(mailbox);

             if ( folder == null ) {
                  return Status.failed("Invalid folder object!");
             }
             folder.open(Folder.READ_ONLY);

	     if( msgcount == -1 ) {
                 msgcount = folder.getMessageCount();
                 if( msgcount < 1 )
                     return Status.failed("Mail folder is empty!");
             }
	     Address[] from  = new Address[1];

             for( int i = 1; i <= msgcount; i++ )
             {
             // Get the message
                MimeMessage msg =  (MimeMessage)folder.getMessage(i);

	        if( msg == null ) {
		    log.println("WARNING: FAILED TO GET MESSAGE NUMBER: "+ i);
		    continue;
	        }
	     // BEGIN UNIT TEST:
		// Get whom the message is from
	        out.println("UNIT TEST "+ i +":  getFrom()");

	        from = msg.getFrom();	// API TEST

	        if( from != null ) {
	            out.println("getFrom() :=> '"+ from[0] +"'");
                    out.println("UNIT TEST "+ i +":  passed\n");
	        } else
		       out.println("WARNING: Message "+ i +" has null From header");
	     // END UNIT TEST:
	     }
	     folder.close(false);
	     store.close();
	     status = Status.passed("OKAY");

        } catch ( Exception e ) {
	     handlException(e);
        }
	return status;
     }
}
