/*
 * Copyright (c) 2002-2015 Oracle and/or its affiliates. All rights reserved.
 */

package javasoft.sqe.tests.javax.mail.internet.InternetAddress;

import java.util.*;
import java.io.*;
import javax.mail.*;
import javax.mail.internet.*;
import com.sun.javatest.*;
import javasoft.sqe.tests.javax.mail.util.MailTest;

/**
 * This class tests the <strong>getType()</strong> API.
 * It does by invoking the test API and then checking
 * the type of the returned object.  <p>
 *
 *		get the type of address  <p>
 * api2test: public String getType()  <p>
 *
 * how2test: Invoke the getType() API, if it returns returns a non-null object
 *	     of type String, then the testcase passes, otherwise it fails.
 */

public class getType_Test extends MailTest {

    public static void main ( String argv[] )
    {
        getType_Test test = new getType_Test();
        Status s = test.run(argv, System.err, System.out);
	s.exit();
    }

    public Status run(String argv[], PrintWriter log, PrintWriter out)
    {
	super.run(argv, log, out);
	parseArgs(argv);	// parse command-line options

        out.println("\nTesting class InternetAddress: getType()\n");

        try {
          // Connect to host server
             Store store = connect2host(protocol, host, user, password);

          // Get a Folder object
	     Folder root = getRootFolder(store);
             Folder folder = root.getFolder(mailbox);

             if( folder == null ) {
                 return Status.failed("Invalid folder object!");
             }
	     folder.open(Folder.READ_ONLY);

	     if( msgcount == -1 ) {
                 msgcount = folder.getMessageCount();
                 if( msgcount < 1 )
                     return Status.failed("Mail folder is empty!");
             }
          // BEGIN UNIT TEST:
	     
	     for( int i = 1; i <= msgcount; i++ )
	     {
	     // Get a Message object
		Message msg = folder.getMessage(i);

		if( msg == null ) {
                    log.println("WARNING: FAILED TO GET MESSAGE NUMBER: "+ i);
                    continue;
		}
		// Get a From address object(s)
		Address[] addrs = msg.getFrom();

		if( addrs == null || addrs.length == 0 ) {
                    log.println("WARNING: FAILED TO GET FROM ADDRESS FOR MESSAGE NUMBER: "+ i);
                    continue;
		}

		InternetAddress addr = (InternetAddress)addrs[0];
		String addtype = addr.getType();	// API TEST

		if ( addtype != null && addtype.equals("rfc822") )
		    out.println("UNIT TEST "+ i +": passed\n");
		else {
		    out.println("UNIT TEST "+ i +": FAILED\n");
		    errors++;
		}
	     }

	     // create new internet address object
	     InternetAddress addr = new InternetAddress("joe@example.com");

	     String addtype = addr.getType();	// API TEST

	     if ( addtype != null && addtype.equals("rfc822") )
		  out.println("UNIT TEST "+ (msgcount+1) +": passed\n");
	     else {
		  out.println("UNIT TEST "+ (msgcount+1) +": FAILED\n");
		  errors++;
	     }
          // END UNIT TEST:
	     folder.close(false);
	     store.close();
	     checkStatus();

        } catch ( Exception e ) {
	     handlException(e);
        }
	return status;
     }
}
